aboutsummaryrefslogtreecommitdiff
path: root/internal/game/game.go
diff options
context:
space:
mode:
Diffstat (limited to 'internal/game/game.go')
-rw-r--r--internal/game/game.go10
1 files changed, 5 insertions, 5 deletions
diff --git a/internal/game/game.go b/internal/game/game.go
index bf7bdc2..b9fb0af 100644
--- a/internal/game/game.go
+++ b/internal/game/game.go
@@ -44,13 +44,13 @@ type Deps struct {
}
// Game is the central orchestrator: it owns the data stores (via the embedded
// Deps), the shared mutable game state (flags, combat tracker, command queue,
// safespots), and the per-session runtime bookkeeping.
type Game struct {
Deps
Hub *net.Hub
- Flags *FlagStore
+ GlobalFlags *GlobalFlagStore
Combat *combat.Tracker
TriggerStore *world.TriggerStore
queue *CommandQueue
@@ -88,7 +88,7 @@ func New(dataDir string, colorConfig *config.ColorsConfig, valConfig config.Vali
ColorConfig: colorConfig,
DataDir: dataDir,
},
- Flags: NewFlagStore(),
+ GlobalFlags: NewGlobalFlagStore(),
Combat: combat.NewTracker(),
TriggerStore: world.NewTriggerStore(),
queue: NewCommandQueue(),
@@ -127,8 +127,8 @@ func (g *Game) SetHub(hub *net.Hub) {
}
}
})
- g.Flags.OnChange(func(name string, value any) {
- g.TriggerStore.FireWorld(name, value)
+ g.GlobalFlags.OnChange(func(name string, value any) {
+ g.TriggerStore.FireGlobal(name, value)
})
}
@@ -44,13 +44,13 @@ type Deps struct {
}
// Game is the central orchestrator: it owns the data stores (via the embedded
-// Deps), the shared mutable game state (flags, combat tracker, command queue,
+// Deps), the shared mutable game state (global flags, combat tracker, command queue,
// safespots), and the per-session runtime bookkeeping.
type Game struct {